@@ -29,7 +29,6 @@ else:
 
 if sys.version_info >= (3, 8):
     create_task = asyncio.create_task
-    Task = asyncio.Task
 
 elif sys.version_info >= (3, 7):
 
@@ -38,7 +37,6 @@ elif sys.version_info >= (3, 7):
     ) -> "asyncio.Future[T]":
         return asyncio.create_task(coro)
 
-    Task = asyncio.Future
 
 else:
 
@@ -47,7 +45,6 @@ else:
     ) -> "asyncio.Future[T]":
         return asyncio.ensure_future(coro)
 
-    Task = asyncio.Future
 
 if sys.version_info >= (3, 9):
     from zoneinfo import ZoneInfo
